__version__ = "3.1.0"
__author__ = "Maxime Barbier"

from .json_include import (
    JSONInclude,
    build_str,
    build_json,
)
